==> aroundme_0_3_3.zip: aroundme_0_3_3/www/template/default.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";?>
<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="content-type" content="text/html;charset=iso-8859-1" />
<title><?php echo "aroundme: " . $lang['node_num'] . " / " . $lang['node_name'];?></title>
<style type="text/css">
<!--
@import url(template/aroundme.css);

-->
</style>


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body bgcolor="#FFFFFF">

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td height="60" valign="middle">
			<span class="txt_main_menu"><?php echo $lang['node_num'];?></span>&nbsp;&nbsp;&#47;&nbsp;
			<span class="txt_main_menu_on"><?php echo $lang['node_name'];?></span><br />
		</td>
		<td valign="top" align="right">
			<?php
			if (isset($lang['arr_lang_name']) && count($lang['arr_lang_name']) > 1) {
			$end_num = 1;
			foreach($lang['arr_lang_name'] as $key => $i): ?>

				<?php
				if ($language_id == $key) {
				?>
				<span class="txt_footer"><?php echo $i;?></span>
				<?php
				}
				else {
				?>
				<a href="<?php echo $current_filename;?>?language_id=<?php echo $key;?>" class="txt_footer_link"><?php echo $i;?></a>
				<?php
				}
				?>

			<?php
			if ($end_num < count($lang['arr_lang_name'])) {
				echo "&nbsp;&nbsp;&#47;&nbsp;&nbsp;";
				$end_num++;
			}
			endforeach;
			}
			?>
			<br />
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />

<?php
if (isset($error)) {
?>
<table width="760" border="0" cellspacing="0" cellpadding="4">
	<tr>
		<tr>
			<td class="txt_error">
				<?php
				echo "<b>" . $lang['arr_error_title'] . "</b><br />";
				foreach($error as $key => $i):
				echo $lang['arr_error'][$i[1]];
				if (isset($i[2])) {
				    echo ": " . $i[2];
				}
				echo "<br />";
				endforeach;
				?>
			</td>
		</tr>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />
<?php
}
elseif (isset($success)) {
?>
<table width="760" border="0" cellspacing="0" cellpadding="4">
	<tr>
		<tr>
			<td>
				<?php
				echo "<b>" . $lang['arr_success_title'] . "</b><br />";
				foreach($success as $key => $i):
				echo $lang['arr_success'][$i[1]];
				if (isset($i[2])) {
				    echo ": " . $i[2];
				}
				echo "<br />";
				endforeach;
				?>
			</td>
		</tr>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />
<?php
}
?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<?=$content;?>
		</td>
	</tr>
	<tr>
		<td align="center" class="txt_footer">
		<?php echo $lang['copyright'];?><br />
		</td>
	</tr>
</table>

</body>
</html>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/template/default.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<?php echo "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";?>
<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo "aroundme: " . $lang['node_num'] . " / " . $lang['node_name'];?></title>
<style type="text/css">
<!--
@import url(template/aroundme.css);

-->
</style>


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body bgcolor="#ffffff">

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td height="60" valign="middle">
			<span class="txt_main_menu"><?php echo $lang['node_num'];?></span>&nbsp;&nbsp;&#47;&nbsp;
			<span class="txt_main_menu_on"><?php echo $lang['node_name'];?></span><br />
		</td>
		<td valign="top" align="right">
			<?php
			if (isset($lang['arr_lang_name']) && count($lang['arr_lang_name']) > 1) {
			$end_num = 1;
			foreach($lang['arr_lang_name'] as $key => $i): ?>

				<?php
				if ($language_id == $key) {
				?>
				<span class="txt_footer"><?php echo $i;?></span>
				<?php
				}
				else {
				?>
				<a href="<?php echo $current_filename;?>?language_id=<?php echo $key;?>" class="txt_footer_link"><?php echo $i;?></a>
				<?php
				}
				?>

			<?php
			if ($end_num < count($lang['arr_lang_name'])) {
				echo "&nbsp;&nbsp;&#47;&nbsp;&nbsp;";
				$end_num++;
			}
			endforeach;
			}
			?>
			<br />
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />

<?php
if (isset($log[0])) {
?>
<table width="770" border="0" cellspacing="0" cellpadding="4">
	<?php
	foreach($log as $key => $i):
		if (isset($i[0])) {
			unset($error);
			if (isset($error_handling) && $error_handling>0 && isset($i[1])) {
				$error = $lang['arr_error'][$i[0]] . ": " . $i[2] . "<br />";
			}
			elseif (empty($i[1])) {
				$error = $lang['arr_error'][$i[0]] . "<br />";
			}
		}
		
		if (isset($error)) {
	?>
	<tr>
		<td class="txt_error">
			<?php echo $error;?>
		</td>
	</tr>
	<?
	}
	endforeach;
	?>
</table>
<?php
}
?>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />


<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<?php echo $content;?>
		</td>
	</tr>
	<tr>
		<td align="center" class="txt_footer">
		<?php echo $lang['copyright'];?><br />
		</td>
	</tr>
</table>

</body>
</html>
